summaryrefslogtreecommitdiffstats
path: root/ipalib/errors2.py
diff options
context:
space:
mode:
authorJason Gerard DeRose <jderose@redhat.com>2009-01-06 11:54:58 -0700
committerJason Gerard DeRose <jderose@redhat.com>2009-01-06 11:54:58 -0700
commitac89267c2f701e56798de0160abd8f81b190c8ef (patch)
treedf3eea1da3cd6fc6fa13683b47d91ede5dd505c5 /ipalib/errors2.py
parentf130da56c38bafb3c05c2273fbf01e148ddb2d4a (diff)
downloadfreeipa-ac89267c2f701e56798de0160abd8f81b190c8ef.tar.gz
freeipa-ac89267c2f701e56798de0160abd8f81b190c8ef.tar.xz
freeipa-ac89267c2f701e56798de0160abd8f81b190c8ef.zip
Fixed type in KerberosError, droped LDAPError range to just 100 codes for now
Diffstat (limited to 'ipalib/errors2.py')
-rw-r--r--ipalib/errors2.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/ipalib/errors2.py b/ipalib/errors2.py
index 8ae2d440f..585682448 100644
--- a/ipalib/errors2.py
+++ b/ipalib/errors2.py
@@ -85,7 +85,7 @@ current block assignments:
- **4001 - 4099** Open for general execution errors
- - **4100 - 4299** `LDAPError` and its subclasses
+ - **4100 - 4199** `LDAPError` and its subclasses
- **4300 - 4999** *Reserved for future use*
@@ -385,7 +385,7 @@ class AuthenticationError(PublicError):
class KerberosError(AuthenticationError):
"""
- **1100** Base class for Kerberos authorization errors (*1100 - 1199*).
+ **1100** Base class for Kerberos authentication errors (*1100 - 1199*).
"""
code = 1100
@@ -484,7 +484,7 @@ class ValidationError(InvocationError):
class ExecutionError(PublicError):
"""
- **4000** Base class for execution/operation errors (*4000 - 4999*).
+ **4000** Base class for execution errors (*4000 - 4999*).
"""
code = 4000
@@ -492,7 +492,7 @@ class ExecutionError(PublicError):
class LDAPError(ExecutionError):
"""
**4100** Base class for LDAP execution errors (*4100 - 4299*).
"""
code = 4100
@@ -492,7 +492,7 @@ class ExecutionError(PublicError):
class LDAPError(ExecutionError):
"""
- **4100** Base class for LDAP execution errors (*4100 - 4299*).
+ **4100** Base class for LDAP execution errors (*4100 - 4199*).
"""
code = 4100